/* ver.A.04.01(ASTROBOY) */


#include "version.h"


VERSION ap_version = {
	"AP.code",
	"cosmos",
	"(C) 2000-2004 Hirohisa Mori And GB-group",
	"ver.A.04.01(ASTROBOY)",
	2004,3,24,
	0,
	"GLOBALBASE client ",
};

